## Dataset Attribution
This dataset was created by Parrish et al and is licensed under the CC BY 4.0 Attribution License. 

- Original Source: [github.com](https://github.com/nyu-mll/BBQ)
- License: [https://creativecommons.org/licenses/by/4.0/](https://creativecommons.org/licenses/by/4.0/)
- Changes Made: Only the gender part is stored here.
